=== modified file 'bzrlib/benchmarks/bench_rocks.py'
--- bzrlib/benchmarks/bench_rocks.py	2006-06-11 04:20:08 +0000
+++ bzrlib/benchmarks/bench_rocks.py	2006-06-11 21:26:20 +0000
@@ -23,4 +23,4 @@
 
     def test_rocks(self):
         """Test the startup overhead by running a do-nothing command"""
-        self.time(self.run_bzr_external, 'rocks')
+        self.time(self.run_bzr_subprocess, 'rocks')

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-06-08 14:59:53 +0000
+++ bzrlib/tests/__init__.py	2006-06-11 21:26:20 +0000
@@ -721,20 +721,27 @@
             encoding = bzrlib.user_encoding
         return self.run_bzr(*args, **kwargs)[0].decode(encoding)
 
-    def run_bzr_external(self, *args, **kwargs):
+    def run_bzr_subprocess(self, *args, **kwargs):
+        """Run bzr in a subprocess for testing.
+
+        This starts a new Python interpreter and runs bzr in there. 
+        This should only be used for tests that have a justifiable need for
+        this isolation: e.g. they are testing startup time, or signal
+        handling, or early startup code, etc.  Subprocess code can't be 
+        profiled or debugged so easily.
+        """
         bzr_path = os.path.dirname(os.path.dirname(bzrlib.__file__))+'/bzr'
         if len(args) == 1:
             args = shlex.split(args[0])
         args = list(args)
-        process = Popen([bzr_path]+args, stdout=PIPE, stderr=PIPE)
+        process = Popen([sys.executable, bzr_path]+args, stdout=PIPE, 
+                         stderr=PIPE)
         out = process.stdout.read()
         err = process.stderr.read()
         retcode = process.wait()
-        supplied_retcode = kwargs.get('retcode')
+        supplied_retcode = kwargs.get('retcode', 0)
         if supplied_retcode is not None:
             assert supplied_retcode == retcode
-        else:
-            assert retcode == 0
         return [out, err]
 
     def check_inventory_shape(self, inv, shape):

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-06-08 14:59:53 +0000
+++ bzrlib/tests/test_selftest.py	2006-06-11 21:26:20 +0000
@@ -680,16 +680,17 @@
             test_suite_factory=factory)
         self.assertEqual([True], factory_called)
 
-    def test_run_bzr_external(self):
+    def test_run_bzr_subprocess(self):
         """The run_bzr_helper_external comand behaves nicely."""
-        result = self.run_bzr_external('--version')
+        result = self.run_bzr_subprocess('--version')
         self.assertContainsRe(result[0], 'is free software')
-        self.assertRaises(AssertionError, self.run_bzr_external, '--versionn')
-        result = self.run_bzr_external('--versionn', retcode=3)
+        self.assertRaises(AssertionError, self.run_bzr_subprocess, 
+                          '--versionn')
+        result = self.run_bzr_subprocess('--versionn', retcode=3)
         self.assertContainsRe(result[1], 'unknown command')
-        err = self.run_bzr_external('merge --merge-type "magic merge"', 
-                                    retcode=3)[1]
+        err = self.run_bzr_subprocess('merge --merge-type "magic merge"', 
+                                      retcode=3)[1]
         self.assertContainsRe(err, 'No known merge type magic merge')
-        err = self.run_bzr_external('merge', '--merge-type', 'magic merge', 
-                                    retcode=3)[1]
+        err = self.run_bzr_subprocess('merge', '--merge-type', 'magic merge', 
+                                      retcode=3)[1]
         self.assertContainsRe(err, 'No known merge type magic merge')

